==> ktorrent-3.3.4.tar.xz: ktorrent-3.3.4/ktorrent/app.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Adam Treat                                      *
 *   treat@kde.org                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/

#ifndef _KTAPP_H_
#define _KTAPP_H_

#include <kuniqueapplication.h>

namespace kt
{
	class GUI;

	class App : public KUniqueApplication
	{
		Q_OBJECT
	public:
		App();
		virtual ~App();

		virtual int newInstance();
	private:
		static GUI* main_widget;
	};
}

#endif // _KTORRENTAPP_H_

==> ktorrent_5.1.0.orig.tar.xz: ktorrent-5.1.0/ktorrent/app.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Adam Treat                                      *
 *   treat@kde.org                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/

#ifndef _KTAPP_H_
#define _KTAPP_H_

#include <QApplication>

namespace kt
{
    class App : public QApplication
    {
    public:
        App(int argc, char** argv): QApplication(argc, argv) {}
        ~App(){}

        //bool notify(QObject* receiver, QEvent* event);
    };
}

#endif // _KTORRENTAPP_H_
